==> datastar_lustre-1.0.0.tar: src/datastar@ds_lustre.erl <==
-module(datastar@ds_lustre).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([data_attr/2, data_attrs/1, data_bind/1, data_classes/1, data_class/2, data_computed/2, data_custom_validity/1, data_indicator/1, data_star_ignore/0, data_on/2, data_on_click/1, data_on_load/1, data_on_raf/1, data_on_signal_change/1, data_on_specific_signal_change/2, data_on_submit/1, data_persist/1, data_replace_url/1, data_ref/1, data_scroll_into_view/0, data_show/1, data_signal/2, data_signals/1, data_text/1, data_view_transition/1]).

-if(?OTP_RELEASE >= 27).
-define(MODULEDOC(Str), -moduledoc(Str)).
-define(DOC(Str), -doc(Str)).
-else.
-define(MODULEDOC(Str), -compile([])).
-define(DOC(Str), -compile([])).
-endif.

?MODULEDOC(
    " This module provides functions to add Datastar data attributes to html elements\n"
    " as shown here <https://data-star.dev/reference/attribute_plugins>\n"
).

-file("src/datastar/ds_lustre.gleam", 11).
-spec serialise_expressions(list({binary(), binary()})) -> binary().
serialise_expressions(Pairs) ->
    Inner = begin
        _pipe = Pairs,
        _pipe@1 = gleam@list:map(
            _pipe,
            fun(Pair) ->
                {Key, Expression} = Pair,
                <<<<<<"'"/utf8, Key/binary>>/binary, "':"/utf8>>/binary,
                    Expression/binary>>
            end
        ),
        gleam@string:join(_pipe@1, <<","/utf8>>)
    end,
    <<<<"{"/utf8, Inner/binary>>/binary, "}"/utf8>>.

-file("src/datastar/ds_lustre.gleam", 35).
?DOC(
    " Sets the value of any HTML attribute to an expression, and keeps it in sync.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-attr>.\n"
    "\n"
    " e.g.\n"
    " ```gleam\n"
    " div([ds_lustre.data_attr(\"title\", \"$foo\")], [])\n"
    " ```\n"
    "\n"
    " ```html\n"
    " <div data-attr-title=\"$foo\"></div>\n"
    " ```\n"
).
-spec data_attr(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_attr(Key, Expression) ->
    lustre@attribute:attribute(<<"data-attr-"/utf8, Key/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 45).
?DOC(
    " Similar to `data_attr` but sets multiple attrs at once.\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-attr=\"{title: $foo, disabled: $bar}\"></div>\n"
    " ```\n"
).
-spec data_attrs(list({binary(), binary()})) -> lustre@internals@vdom:attribute(any()).
data_attrs(Pairs) ->
    Expression = serialise_expressions(Pairs),
    lustre@attribute:attribute(<<"data-attr"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 62).
?DOC(
    " Creates a signal and sets up two-way data binding.\n"
    " This takes the name of a signal (without the $).\n"
    "\n"
    " ```gleam\n"
    " ds_lustre.data_bind(\"first_name\")\n"
    " ```\n"
    "\n"
    " ```html\n"
    " <input data-bind=\"first_name\" />\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-bind>\n"
).
-spec data_bind(binary()) -> lustre@internals@vdom:attribute(any()).
data_bind(Value) ->
    lustre@attribute:attribute(<<"data-bind"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 81).
?DOC(
    " Control multiple classes at once\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-class>\n"
).
-spec data_classes(list({binary(), binary()})) -> lustre@internals@vdom:attribute(any()).
data_classes(Pairs) ->
    Expression = serialise_expressions(Pairs),
    lustre@attribute:attribute(<<"data-class"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 74).
?DOC(
    " Adds or removes a class.\n"
    "\n"
    " The first value is the class name.\n"
    "\n"
    " The second value is an expression.\n"
    "   e.g. a signal $selected or a complex expression\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-class>\n"
).
-spec data_class(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_class(Key, Expression) ->
    data_classes([{Key, Expression}]).

-file("src/datastar/ds_lustre.gleam", 90).
?DOC(
    " Creates a signal that is computed based on an expression.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-computed>\n"
).
-spec data_computed(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_computed(Key, Value) ->
    lustre@attribute:attribute(<<"data-computed-"/utf8, Key/binary>>, Value).

-file("src/datastar/ds_lustre.gleam", 95).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-custom-validity>\n").
-spec data_custom_validity(binary()) -> lustre@internals@vdom:attribute(any()).
data_custom_validity(Expression) ->
    lustre@attribute:attribute(<<"data-custom-validity"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 100).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-indicator>\n").
-spec data_indicator(binary()) -> lustre@internals@vdom:attribute(any()).
data_indicator(Signal) ->
    lustre@attribute:attribute(<<"data-indicator"/utf8>>, Signal).

-file("src/datastar/ds_lustre.gleam", 105).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-star-ignore>\n").
-spec data_star_ignore() -> lustre@internals@vdom:attribute(any()).
data_star_ignore() ->
    lustre@attribute:attribute(<<"data-star-ignore"/utf8>>, <<""/utf8>>).

-file("src/datastar/ds_lustre.gleam", 112).
?DOC(
    " Attaches an event listener to an element.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on>\n"
).
-spec data_on(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_on(Event, Expression) ->
    lustre@attribute:attribute(<<"data-on-"/utf8, Event/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 117).
?DOC(" Shorcut for `data_on(\"click\", _)`.\n").
-spec data_on_click(binary()) -> lustre@internals@vdom:attribute(any()).
data_on_click(Expression) ->
    data_on(<<"click"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 124).
?DOC(
    " Runs an expression when the element is loaded into the DOM.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-load>\n"
).
-spec data_on_load(binary()) -> lustre@internals@vdom:attribute(any()).
data_on_load(Expression) ->
    data_on(<<"load"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 131).
?DOC(
    " Runs an expression on every requestAnimationFrame event.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-raf>\n"
).
-spec data_on_raf(binary()) -> lustre@internals@vdom:attribute(any()).
data_on_raf(Expression) ->
    data_on(<<"raf"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 138).
?DOC(
    " Runs an expression whenever a signal changes.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-signal-change>\n"
).
-spec data_on_signal_change(binary()) -> lustre@internals@vdom:attribute(any()).
data_on_signal_change(Expression) ->
    data_on(<<"signal-change"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 145).
?DOC(
    " Runs an expression whenever a signal changes.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-signal-change>\n"
).
-spec data_on_specific_signal_change(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_on_specific_signal_change(Signal, Expression) ->
    data_on(<<"signal-change-"/utf8, Signal/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 152).
?DOC(
    " Shorcut for `data_on(\"submit\", _)`.\n"
    "\n"
    " This prevents the default submission behavior of forms.\n"
).
-spec data_on_submit(binary()) -> lustre@internals@vdom:attribute(any()).
data_on_submit(Expression) ->
    data_on(<<"submit"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 164).
?DOC(
    " Persists signals in local storage\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-persist></div>\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-persist>\n"
).
-spec data_persist(binary()) -> lustre@internals@vdom:attribute(any()).
data_persist(Signals) ->
    lustre@attribute:attribute(<<"data-persist"/utf8>>, Signals).

-file("src/datastar/ds_lustre.gleam", 169).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-replace-url>\n").
-spec data_replace_url(binary()) -> lustre@internals@vdom:attribute(any()).
data_replace_url(Value) ->
    lustre@attribute:attribute(<<"data-replace-url"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 176).
?DOC(
    " Creates a signal that is a reference to this DOM element.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-ref>\n"
).
-spec data_ref(binary()) -> lustre@internals@vdom:attribute(any()).
data_ref(Value) ->
    lustre@attribute:attribute(<<"data-ref"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 181).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-scroll-into-view>\n").
-spec data_scroll_into_view() -> lustre@internals@vdom:attribute(any()).
data_scroll_into_view() ->
    lustre@attribute:attribute(<<"data-scroll-into-view"/utf8>>, <<""/utf8>>).

-file("src/datastar/ds_lustre.gleam", 188).
?DOC(
    " Show or hides an element based on an expression.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-show>\n"
).
-spec data_show(binary()) -> lustre@internals@vdom:attribute(any()).
data_show(Value) ->
    lustre@attribute:attribute(<<"data-show"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 195).
?DOC(
    " Merges one signals into the existing signals.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-signals>\n"
).
-spec data_signal(binary(), binary()) -> lustre@internals@vdom:attribute(any()).
data_signal(Signal, Value) ->
    lustre@attribute:attribute(<<"data-signals-"/utf8, Signal/binary>>, Value).

-file("src/datastar/ds_lustre.gleam", 202).
?DOC(
    " Merges one or more signals into the existing signals.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-signals>\n"
).
-spec data_signals(list({binary(), gleam@json:json()})) -> lustre@internals@vdom:attribute(any()).
data_signals(Signals) ->
    Signals_json = begin
        _pipe = Signals,
        _pipe@1 = maps:from_list(_pipe),
        _pipe@2 = gleam@json:dict(
            _pipe@1,
            fun gleam@function:identity/1,
            fun gleam@function:identity/1
        ),
        gleam@json:to_string(_pipe@2)
    end,
    lustre@attribute:attribute(<<"data-signals"/utf8>>, Signals_json).

-file("src/datastar/ds_lustre.gleam", 220).
?DOC(
    " Binds the text content of an element to an expression.\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-text=\"$foo\"></div>\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-text>\n"
).
-spec data_text(binary()) -> lustre@internals@vdom:attribute(any()).
data_text(Value) ->
    lustre@attribute:attribute(<<"data-text"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 225).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-view-transition>\n").
-spec data_view_transition(binary()) -> lustre@internals@vdom:attribute(any()).
data_view_transition(Value) ->
    lustre@attribute:attribute(<<"data-view-transition"/utf8>>, Value).

==> datastar_lustre-2.0.0.tar: src/datastar@ds_lustre.erl <==
-module(datastar@ds_lustre).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([data_attr/2, data_attrs/1, data_bind/1, data_classes/1, data_class/2, data_computed/2, data_custom_validity/1, data_indicator/1, data_star_ignore/0, data_on/2, data_on_click/1, data_on_load/1, data_on_raf/1, data_on_signal_change/1, data_on_specific_signal_change/2, data_on_submit/1, data_persist/1, data_replace_url/1, data_ref/1, data_scroll_into_view/0, data_show/1, data_signal/2, data_signals/1, data_text/1, data_view_transition/1]).

-if(?OTP_RELEASE >= 27).
-define(MODULEDOC(Str), -moduledoc(Str)).
-define(DOC(Str), -doc(Str)).
-else.
-define(MODULEDOC(Str), -compile([])).
-define(DOC(Str), -compile([])).
-endif.

?MODULEDOC(
    " This module provides functions to add Datastar data attributes to html elements\n"
    " as shown here <https://data-star.dev/reference/attribute_plugins>\n"
).

-file("src/datastar/ds_lustre.gleam", 11).
-spec serialise_expressions(list({binary(), binary()})) -> binary().
serialise_expressions(Pairs) ->
    Inner = begin
        _pipe = Pairs,
        _pipe@1 = gleam@list:map(
            _pipe,
            fun(Pair) ->
                {Key, Expression} = Pair,
                <<<<<<"'"/utf8, Key/binary>>/binary, "':"/utf8>>/binary,
                    Expression/binary>>
            end
        ),
        gleam@string:join(_pipe@1, <<","/utf8>>)
    end,
    <<<<"{"/utf8, Inner/binary>>/binary, "}"/utf8>>.

-file("src/datastar/ds_lustre.gleam", 35).
?DOC(
    " Sets the value of any HTML attribute to an expression, and keeps it in sync.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-attr>.\n"
    "\n"
    " e.g.\n"
    " ```gleam\n"
    " div([ds_lustre.data_attr(\"title\", \"$foo\")], [])\n"
    " ```\n"
    "\n"
    " ```html\n"
    " <div data-attr-title=\"$foo\"></div>\n"
    " ```\n"
).
-spec data_attr(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_attr(Key, Expression) ->
    lustre@attribute:attribute(<<"data-attr-"/utf8, Key/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 45).
?DOC(
    " Similar to `data_attr` but sets multiple attrs at once.\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-attr=\"{title: $foo, disabled: $bar}\"></div>\n"
    " ```\n"
).
-spec data_attrs(list({binary(), binary()})) -> lustre@vdom@vattr:attribute(any()).
data_attrs(Pairs) ->
    Expression = serialise_expressions(Pairs),
    lustre@attribute:attribute(<<"data-attr"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 62).
?DOC(
    " Creates a signal and sets up two-way data binding.\n"
    " This takes the name of a signal (without the $).\n"
    "\n"
    " ```gleam\n"
    " ds_lustre.data_bind(\"first_name\")\n"
    " ```\n"
    "\n"
    " ```html\n"
    " <input data-bind=\"first_name\" />\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-bind>\n"
).
-spec data_bind(binary()) -> lustre@vdom@vattr:attribute(any()).
data_bind(Value) ->
    lustre@attribute:attribute(<<"data-bind"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 81).
?DOC(
    " Control multiple classes at once\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-class>\n"
).
-spec data_classes(list({binary(), binary()})) -> lustre@vdom@vattr:attribute(any()).
data_classes(Pairs) ->
    Expression = serialise_expressions(Pairs),
    lustre@attribute:attribute(<<"data-class"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 74).
?DOC(
    " Adds or removes a class.\n"
    "\n"
    " The first value is the class name.\n"
    "\n"
    " The second value is an expression.\n"
    "   e.g. a signal $selected or a complex expression\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-class>\n"
).
-spec data_class(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_class(Key, Expression) ->
    data_classes([{Key, Expression}]).

-file("src/datastar/ds_lustre.gleam", 90).
?DOC(
    " Creates a signal that is computed based on an expression.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-computed>\n"
).
-spec data_computed(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_computed(Key, Value) ->
    lustre@attribute:attribute(<<"data-computed-"/utf8, Key/binary>>, Value).

-file("src/datastar/ds_lustre.gleam", 95).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-custom-validity>\n").
-spec data_custom_validity(binary()) -> lustre@vdom@vattr:attribute(any()).
data_custom_validity(Expression) ->
    lustre@attribute:attribute(<<"data-custom-validity"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 100).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-indicator>\n").
-spec data_indicator(binary()) -> lustre@vdom@vattr:attribute(any()).
data_indicator(Signal) ->
    lustre@attribute:attribute(<<"data-indicator"/utf8>>, Signal).

-file("src/datastar/ds_lustre.gleam", 105).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-star-ignore>\n").
-spec data_star_ignore() -> lustre@vdom@vattr:attribute(any()).
data_star_ignore() ->
    lustre@attribute:attribute(<<"data-star-ignore"/utf8>>, <<""/utf8>>).

-file("src/datastar/ds_lustre.gleam", 112).
?DOC(
    " Attaches an event listener to an element.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on>\n"
).
-spec data_on(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_on(Event, Expression) ->
    lustre@attribute:attribute(<<"data-on-"/utf8, Event/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 117).
?DOC(" Shorcut for `data_on(\"click\", _)`.\n").
-spec data_on_click(binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_click(Expression) ->
    data_on(<<"click"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 124).
?DOC(
    " Runs an expression when the element is loaded into the DOM.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-load>\n"
).
-spec data_on_load(binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_load(Expression) ->
    data_on(<<"load"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 131).
?DOC(
    " Runs an expression on every requestAnimationFrame event.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-raf>\n"
).
-spec data_on_raf(binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_raf(Expression) ->
    data_on(<<"raf"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 138).
?DOC(
    " Runs an expression whenever a signal changes.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-signal-change>\n"
).
-spec data_on_signal_change(binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_signal_change(Expression) ->
    data_on(<<"signal-change"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 145).
?DOC(
    " Runs an expression whenever a signal changes.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-on-signal-change>\n"
).
-spec data_on_specific_signal_change(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_specific_signal_change(Signal, Expression) ->
    data_on(<<"signal-change-"/utf8, Signal/binary>>, Expression).

-file("src/datastar/ds_lustre.gleam", 152).
?DOC(
    " Shorcut for `data_on(\"submit\", _)`.\n"
    "\n"
    " This prevents the default submission behavior of forms.\n"
).
-spec data_on_submit(binary()) -> lustre@vdom@vattr:attribute(any()).
data_on_submit(Expression) ->
    data_on(<<"submit"/utf8>>, Expression).

-file("src/datastar/ds_lustre.gleam", 164).
?DOC(
    " Persists signals in local storage\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-persist></div>\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-persist>\n"
).
-spec data_persist(binary()) -> lustre@vdom@vattr:attribute(any()).
data_persist(Signals) ->
    lustre@attribute:attribute(<<"data-persist"/utf8>>, Signals).

-file("src/datastar/ds_lustre.gleam", 169).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-replace-url>\n").
-spec data_replace_url(binary()) -> lustre@vdom@vattr:attribute(any()).
data_replace_url(Value) ->
    lustre@attribute:attribute(<<"data-replace-url"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 176).
?DOC(
    " Creates a signal that is a reference to this DOM element.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-ref>\n"
).
-spec data_ref(binary()) -> lustre@vdom@vattr:attribute(any()).
data_ref(Value) ->
    lustre@attribute:attribute(<<"data-ref"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 181).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-scroll-into-view>\n").
-spec data_scroll_into_view() -> lustre@vdom@vattr:attribute(any()).
data_scroll_into_view() ->
    lustre@attribute:attribute(<<"data-scroll-into-view"/utf8>>, <<""/utf8>>).

-file("src/datastar/ds_lustre.gleam", 188).
?DOC(
    " Show or hides an element based on an expression.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-show>\n"
).
-spec data_show(binary()) -> lustre@vdom@vattr:attribute(any()).
data_show(Value) ->
    lustre@attribute:attribute(<<"data-show"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 195).
?DOC(
    " Merges one signals into the existing signals.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-signals>\n"
).
-spec data_signal(binary(), binary()) -> lustre@vdom@vattr:attribute(any()).
data_signal(Signal, Value) ->
    lustre@attribute:attribute(<<"data-signals-"/utf8, Signal/binary>>, Value).

-file("src/datastar/ds_lustre.gleam", 202).
?DOC(
    " Merges one or more signals into the existing signals.\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-signals>\n"
).
-spec data_signals(list({binary(), gleam@json:json()})) -> lustre@vdom@vattr:attribute(any()).
data_signals(Signals) ->
    Signals_json = begin
        _pipe = Signals,
        _pipe@1 = maps:from_list(_pipe),
        _pipe@2 = gleam@json:dict(
            _pipe@1,
            fun gleam@function:identity/1,
            fun gleam@function:identity/1
        ),
        gleam@json:to_string(_pipe@2)
    end,
    lustre@attribute:attribute(<<"data-signals"/utf8>>, Signals_json).

-file("src/datastar/ds_lustre.gleam", 220).
?DOC(
    " Binds the text content of an element to an expression.\n"
    "\n"
    " e.g.\n"
    " ```html\n"
    " <div data-text=\"$foo\"></div>\n"
    " ```\n"
    "\n"
    " See <https://data-star.dev/reference/attribute_plugins#data-text>\n"
).
-spec data_text(binary()) -> lustre@vdom@vattr:attribute(any()).
data_text(Value) ->
    lustre@attribute:attribute(<<"data-text"/utf8>>, Value).

-file("src/datastar/ds_lustre.gleam", 225).
?DOC(" See <https://data-star.dev/reference/attribute_plugins#data-view-transition>\n").
-spec data_view_transition(binary()) -> lustre@vdom@vattr:attribute(any()).
data_view_transition(Value) ->
    lustre@attribute:attribute(<<"data-view-transition"/utf8>>, Value).
